@@ -2,15 +2,15 @@
 from __future__ import annotations
 
 import asyncio
-from collections.abc import Awaitable, Callable
 import socket
+from collections.abc import Awaitable, Callable
 from typing import Any, Optional
 from uuid import uuid4
 
 import aiohttp
 
-from systembridgeconnector.base import Base
-from systembridgeconnector.const import (
+from .base import Base
+from .const import (
     EVENT_API_KEY,
     EVENT_DATA,
     EVENT_EVENT,
@@ -43,26 +43,27 @@ from systembridgeconnector.const import (
     TYPE_POWER_SLEEP,
     TYPE_REGISTER_DATA_LISTENER,
 )
-from systembridgeconnector.exceptions import (
+from .exceptions import (
     AuthenticationException,
     BadMessageException,
     ConnectionClosedException,
     ConnectionErrorException,
 )
-from systembridgeconnector.models.get_data import GetData
-from systembridgeconnector.models.keyboard_key import KeyboardKey
-from systembridgeconnector.models.keyboard_text import KeyboardText
-from systembridgeconnector.models.media_directories import MediaDirectories
-from systembridgeconnector.models.media_files import File as MediaFile, MediaFiles
-from systembridgeconnector.models.media_get_file import MediaGetFile
-from systembridgeconnector.models.media_get_files import MediaGetFiles
-from systembridgeconnector.models.notification import Notification
-from systembridgeconnector.models.open_path import OpenPath
-from systembridgeconnector.models.open_url import OpenUrl
-from systembridgeconnector.models.register_data_listener import RegisterDataListener
-from systembridgeconnector.models.request import Request
-from systembridgeconnector.models.response import Response
-from systembridgeconnector.models.update import Update
+from .models.get_data import GetData
+from .models.keyboard_key import KeyboardKey
+from .models.keyboard_text import KeyboardText
+from .models.media_directories import MediaDirectories
+from .models.media_files import File as MediaFile
+from .models.media_files import MediaFiles
+from .models.media_get_file import MediaGetFile
+from .models.media_get_files import MediaGetFiles
+from .models.notification import Notification
+from .models.open_path import OpenPath
+from .models.open_url import OpenUrl
+from .models.register_data_listener import RegisterDataListener
+from .models.request import Request
+from .models.response import Response
+from .models.update import Update
 
 
 class WebSocketClient(Base):
@@ -90,7 +91,7 @@ class WebSocketClient(Base):
 
     async def _send_message(
         self,
-        request: Request,
+        request,
         wait_for_response: bool = True,
         response_type: Optional[str] = None,
     ) -> Response:
@@ -110,11 +111,9 @@ class WebSocketClient(Base):
             finally:
                 self._responses.pop(request.id)
         return Response(
-            **{
-                EVENT_ID: request.id,
-                EVENT_TYPE: "N/A",
-                EVENT_MESSAGE: "Message sent",
-            }
+            id=request.id,
+            type="N/A",
+            message="Message sent",
         )
 
     async def close(self) -> None:
@@ -133,9 +132,14 @@ class WebSocketClient(Base):
         if session:
             self._session = session
         else:
+            self._logger.info("Creating new aiohttp client session")
             self._session = aiohttp.ClientSession()
         url = f"ws://{self._api_host}:{self._api_port}/api/websocket"
-        self._logger.info("Connecting to WebSocket: %s", url)
+        self._logger.info(
+            "Connecting to WebSocket: %s (aiohttp: %s)",
+            url,
+            aiohttp.__version__,
+        )
         try:
             self._websocket = await self._session.ws_connect(url=url, heartbeat=30)
         except (
